==> libc-4.7.6.tar.gz: libc/libio/iofgets.c <==
/* 
Copyright (C) 1993 Free Software Foundation

This file is part of the GNU IO Library.  This library is free
software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option)
any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU CC; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

As a special exception, if you link this library with files
compiled with a GNU compiler to produce an executable, this does not cause
the resulting executable to be covered by the GNU General Public License.
This exception does not however invalidate any other reasons why
the executable file might be covered by the GNU General Public License. */

#include "libioP.h"

char*
_IO_fgets(buf, n, fp)
     char* buf;
     int n;
     _IO_FILE* fp;
{
  _IO_size_t count;
  CHECK_FILE(fp, NULL);
  if (n <= 0)
    return NULL;
  count = _IO_getline(fp, buf, n - 1, '\n', 1);
  if (count == 0 || (fp->_IO_file_flags & _IO_ERR_SEEN))
    return NULL;
  buf[count] = 0;
  return buf;
}

#if defined(__ELF__) || defined(__GNU_LIBRARY__)
#include <gnu-stabs.h>
#ifdef weak_alias
weak_alias (_IO_fgets, fgets);
#endif
#endif

==> libc-5.4.46.tar.gz: libc/libio/iofgets.c <==
/* 
Copyright (C) 1993 Free Software Foundation

This file is part of the GNU IO Library.  This library is free
software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option)
any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this library; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

As a special exception, if you link this library with files
compiled with a GNU compiler to produce an executable, this does not cause
the resulting executable to be covered by the GNU General Public License.
This exception does not however invalidate any other reasons why
the executable file might be covered by the GNU General Public License. */

#include "libioP.h"

char*
DEFUN(_IO_fgets, (buf, n, fp),
      char* buf AND int n AND _IO_FILE* fp)
{
  _IO_size_t count;
  char *result;
  int old_error;
  CHECK_FILE(fp, NULL);
  if (n <= 0)
    return NULL;
  old_error = fp->_IO_file_flags & _IO_ERR_SEEN;
  fp->_IO_file_flags &= ~_IO_ERR_SEEN;
  count = _IO_getline(fp, buf, n - 1, '\n', 1);
  if (count == 0 || (fp->_IO_file_flags & _IO_ERR_SEEN))
  {
    result = NULL;
  }
  else
  {
    buf[count] = '\0';
    result = buf;
  }
  fp->_IO_file_flags |= old_error;
  return result;
}

#if defined(__ELF__) || defined(__GNU_LIBRARY__)
#include <gnu-stabs.h>
#ifdef weak_alias
weak_alias (_IO_fgets, fgets);
#endif
#endif
